==> mysql-query-browser_1.1.6.orig.tar.gz: mysql-query-browser-1.1.6/mysql-gui-common/source/java/com/mysql/grt/GrtCallback.java <==
package com.mysql.grt;

public interface GrtCallback {
	public abstract void setApplicationPath(String applicationPath);
	
	public abstract String callGrtFunction(long myx_grt_pointer, String module,
			String functionName, String arguments);
	
	public abstract Object getGrtGlobalById(long myx_grt_pointer, 
			String id);
	
	public abstract Object getGrtGlobalAsObject(long myx_grt_pointer, 
			String objectPath);
	
	public abstract String getGrtGlobalAsString(long myx_grt_pointer, 
			String objectPath);
	
	public abstract int getGrtGlobalAsInt(long myx_grt_pointer, 
			String objectPath);
	
	public abstract double getGrtGlobalAsReal(long myx_grt_pointer, 
			String objectPath);
	
	public abstract void setGrtGlobalFromObject(long myx_grt_pointer, 
			String objectPath, Object value);

	public abstract void setGrtGlobalFromString(long myx_grt_pointer, 
			String objectPath, String value);
	
	public abstract void setGrtGlobalFromInt(long myx_grt_pointer, 
			String objectPath, int value);
	
	public abstract void setGrtGlobalFromReal(long myx_grt_pointer, 
			String objectPath, double value);
	
	public abstract int getGrtGlobalListSize(long myx_grt_pointer, 
			String objectPath);

	public abstract Object getGrtGlobalListItem(long myx_grt_pointer, 
			String objectPath, int index);
	
	public abstract void addGrtGlobalListItem(long myx_grt_pointer, 
			String objectPath, Object item);
	
	public abstract void removeGrtGlobalListItem(long myx_grt_pointer, 
			String objectPath, int index);
	
	public abstract Object getGrtGlobalDictItem(long myx_grt_pointer, 
			String objectPath, String key);
	
	public abstract void addGrtGlobalDictItem(long myx_grt_pointer, 
			String objectPath, String key, Object value);
	
	public abstract void removeGrtGlobalDictItem(long myx_grt_pointer, 
			String objectPath, String key);

}

==> mysql-query-browser_1.1.12.orig.tar.gz: mysql-query-browser-1.1.12/mysql-gui-common/source/java/com/mysql/grt/GrtCallback.java <==
package com.mysql.grt;

public interface GrtCallback {
	public abstract void setApplicationPath(String applicationPath);

	public abstract String callGrtFunction(long myx_grt_pointer, String module,
			String functionName, String arguments);

	public abstract Object getGrtGlobalById(long myx_grt_pointer, String id);

	public abstract Object getGrtGlobalAsObject(long myx_grt_pointer,
			String objectPath);

	public abstract String getGrtGlobalAsString(long myx_grt_pointer,
			String objectPath);

	public abstract int getGrtGlobalAsInt(long myx_grt_pointer,
			String objectPath);

	public abstract double getGrtGlobalAsReal(long myx_grt_pointer,
			String objectPath);

	public abstract void setGrtGlobalFromObject(long myx_grt_pointer,
			String objectPath, Object value);

	public abstract void setGrtGlobalFromString(long myx_grt_pointer,
			String objectPath, String value);

	public abstract void setGrtGlobalFromInt(long myx_grt_pointer,
			String objectPath, int value);

	public abstract void setGrtGlobalFromReal(long myx_grt_pointer,
			String objectPath, double value);

	public abstract int getGrtGlobalListSize(long myx_grt_pointer,
			String objectPath);

	public abstract Object getGrtGlobalListItem(long myx_grt_pointer,
			String objectPath, int index);

	public abstract void addGrtGlobalListItem(long myx_grt_pointer,
			String objectPath, Object item);

	public abstract void removeGrtGlobalListItem(long myx_grt_pointer,
			String objectPath, int index);

	public abstract Object getGrtGlobalDictItem(long myx_grt_pointer,
			String objectPath, String key);

	public abstract void addGrtGlobalDictItem(long myx_grt_pointer,
			String objectPath, String key, Object value);

	public abstract void removeGrtGlobalDictItem(long myx_grt_pointer,
			String objectPath, String key);

	public abstract int getGrtGlobalDictKeyCount(long myx_grt_pointer,
			String objectPath);
	
	public abstract String getGrtGlobalDictKey(long myx_grt_pointer,
			String objectPath, int index);
	
	public abstract int processMessages(long myx_grt_pointer, String msgs);
}
